#!/usr/bin/env python3
"""Script for checking Redis status."""

import subprocess
import sys


# WARNING = 1
CRITICAL = 2


def check_redis_status():
    """Check the status of Redis.

    This Nagios plugin is intended to be used to check that Redis is alive and well
    in a Docker container, as used by Contrail networking components.

    Returns:
    status (int): used as return code for Nagios plugins
    message (str): output text.
    """
    check_params = {
        'uptime_in_seconds': 300,
        }

    status = 0
    message = 'OK: Contrail status OK'
    cmd = 'sudo /usr/bin/docker exec redis_redis_1 /usr/local/bin/redis-cli info'
    try:
        output = subprocess.check_output(
            cmd, shell=True, stderr=subprocess.STDOUT
        ).decode('UTF-8')
    except subprocess.CalledProcessError as err:
        message = ('CRITICAL: Could not read Redis status.'
                   ' return code: {} cmd: {} output: {}'.
                   format(err.returncode, err.cmd, err.output))
        status = CRITICAL
        return status, message
    results = {}
    for line in output.splitlines():
        line = line.strip()
        if line and not line.startswith('#'):
            field, value = line.split(':')
            results[field] = value

    # check uptime
    if int(results['uptime_in_seconds']) < check_params['uptime_in_seconds']:
        status = CRITICAL
        message = ('CRITICAL: Uptime for Redis is less than {}'
                   .format(check_params['uptime_in_seconds']))
        return status, message

    return status, message


if __name__ == '__main__':
    status, message = check_redis_status()
    print(message)
    sys.exit(status)
