"""Tests for the Contrail RabbitMQ plugin."""

import os
import shutil
import sys
import tempfile
import unittest
from pathlib import Path
from unittest import mock


# some dep layers only exists in the built charm; mock them out before
# the contrailrabbit imports since those depend on post-build charms.* layers
ch_nrpe_mock = mock.Mock()
sys.modules["charmhelpers.contrib.charmsupport"] = ch_nrpe_mock
hookenv_mock = mock.Mock()
sys.modules["charmhelpers.core.hookenv"] = hookenv_mock

from contrailnrpe import contrailrabbit  # noqa: E402

TESTDIR = Path(__file__).parent
TESTDATA = TESTDIR / "testdata"
CHARMDIR = TESTDIR.parent.parent


class TestContrailRabbit(unittest.TestCase):
    """Tests of contrailrabbit.ContrailRabbitMqCheck."""

    @classmethod
    def setUpClass(cls) -> None:
        """Class setup method."""
        hookenv_mock.charm_dir.return_value = CHARMDIR
        cls.tmp = tmp = Path(tempfile.mkdtemp())
        cls.rootfs = tmp / "rootfs"
        cls.helper = contrailrabbit.ContrailRabbitMqCheck()
        cls.helper.CROND_DIR = str(cls.rootfs / "etc/cron.d")
        cls.helper.NRPE_PLUGINS_DIR = str(cls.rootfs / "usr/local/lib/nagios/plugins")
        cls.helper.NRPE_PLUGINS_UID = euid = os.geteuid()
        cls.helper.NRPE_PLUGINS_GID = egid = os.getegid()
        cls.helper.CRONJOB_SCRIPT_UID = euid
        cls.helper.CRONJOB_SCRIPT_GID = egid
        shutil.copytree(str(TESTDATA), str(cls.rootfs))

    def test_install(self):
        """Test plugin installation."""
        self.helper.install()
        nrpe_cmd = self.rootfs / "usr/local/lib/nagios/plugins/check_rabbitmq_queues"
        with nrpe_cmd.open() as f:
            self.assertTrue("RabbitMQ queue size nagios check." in f.read())
        cron_cmd = (
            self.rootfs / "usr/local/lib/nagios/plugins/collect_rabbitmq_stats.sh"
        )
        with cron_cmd.open() as f:
            self.assertTrue("RABBIT_STATS_DATA_FILE" in f.read())
        cron_entry = self.rootfs / "etc/cron.d/rabbitmq-stats"
        with cron_entry.open() as f:
            self.assertTrue(str(cron_cmd) in f.read())

    def test_remove(self):
        """Test plugin removal."""
        self.helper.install()
        self.helper.remove()
        nrpe_cmd = self.rootfs / "usr/local/lib/nagios/plugins/check_rabbitmq_queues"
        self.assertFalse(nrpe_cmd.exists())
        cron_cmd = (
            self.rootfs / "usr/local/lib/nagios/plugins/collect_rabbitmq_stats.sh"
        )
        self.assertFalse(cron_cmd.exists())
